pub struct VariablesDomainDeclaration { /* private fields */ }Expand description
Represents a single domain declaration for variables, defining their type and iteration scope
Implementations
Sourceimpl VariablesDomainDeclaration
impl VariablesDomainDeclaration
Sourcepub fn new(
variables: Vec<Spanned<Variable>>,
as_type: PreVariableType,
iters: Vec<IterableSet>,
span: InputSpan,
) -> Self
pub fn new( variables: Vec<Spanned<Variable>>, as_type: PreVariableType, iters: Vec<IterableSet>, span: InputSpan, ) -> Self
Creates a new domain declaration
Sourcepub fn variables(&self) -> &Vec<Spanned<Variable>>
pub fn variables(&self) -> &Vec<Spanned<Variable>>
Returns reference to variables in this domain
Sourcepub fn get_type(&self) -> &PreVariableType
pub fn get_type(&self) -> &PreVariableType
Returns reference to the type of variables in this domain
Sourcepub fn static_variables(&self) -> Vec<Spanned<String>>
pub fn static_variables(&self) -> Vec<Spanned<String>>
Returns static (non-compound) variables from this domain
Sourcepub fn iteration(&self) -> &Vec<IterableSet>
pub fn iteration(&self) -> &Vec<IterableSet>
Returns reference to iteration sets
Sourcepub fn compute_domain(
&self,
context: &mut TransformerContext,
fn_context: &FunctionContext<'_>,
) -> Result<Vec<(String, Spanned<VariableType>)>, TransformError>
pub fn compute_domain( &self, context: &mut TransformerContext, fn_context: &FunctionContext<'_>, ) -> Result<Vec<(String, Spanned<VariableType>)>, TransformError>
Computes the complete domain by evaluating all iterations