Spreadable

Trait Spreadable 

pub trait Spreadable {
    // Required method
    fn to_primitive_set(self) -> Result<Vec<Primitive>, TransformError>;
}
Trait for types that can be spread into a sequence of primitives.

Implementors can convert themselves into a vector of primitive values.

Required Methods

fn to_primitive_set(self) -> Result<Vec<Primitive>, TransformError>

Converts self into a vector of primitives.

Returns
  • Ok(Vec<Primitive>) - The sequence of primitives
  • Err(TransformError) - If the value cannot be spread

Implementations on Foreign Types

Source

impl Spreadable for bool

Source

impl Spreadable for f64

Source

impl Spreadable for i64

Source

impl Spreadable for u64

Source

impl Spreadable for String

Implementors