pub trait Spreadable {
// Required method
fn to_primitive_set(self) -> Result<Vec<Primitive>, TransformError>;
}Expand description
Trait for types that can be spread into a sequence of primitives.
Implementors can convert themselves into a vector of primitive values.
Required Methods
Sourcefn to_primitive_set(self) -> Result<Vec<Primitive>, TransformError>
fn to_primitive_set(self) -> Result<Vec<Primitive>, TransformError>
Converts self into a vector of primitives.
Returns
Ok(Vec<Primitive>)- The sequence of primitivesErr(TransformError)- If the value cannot be spread